@@ -228,23 +228,23 @@ c     *      sngl(inci.p.fm.p(4)-inci.p.mass)/
 c     *      Code2massN(int(inci.p.code)),
 c     *      inci.p.code
 c     
-c       write(*,
+       write(*, *)
 c     *  '(i2,1x,i2,1x,f12.2, g13.4, f12.2,1x, f12.2,1x,f7.4,i3)')
 c     * nev, 
 c     *  aTrack.where,   !  observation level. integer*2.  1 is highest.
-c     *  aTrack.p.code,  ! " ", ptclid,    !  ptcl code.  integer*2.
-c     *  aTrack.p.charge,  !  charge,  integer*2 
+     *  aTrack.p.code,  ! " ", ptclid,    !  ptcl code.  integer*2.
+     *  aTrack.p.charge,  !  charge,  integer*2 
 c     *  sngl(aTrack.t), !  relateive arrival time in nsec (NOT sec).
 c                        !  if TimeStructure is F, nonsense.
-c     *  sngl(aTrack.p.fm.e), !  - aTrack.p.mass), ! kinetic energy in GeV
+     *  sngl(aTrack.p.fm.e), !  - aTrack.p.mass), ! kinetic energy in GeV
 c     *  sngl(aTrack.pos.xyz.x), sngl(aTrack.pos.xyz.y),  !  x, y, erg in m
 c     *  sngl(aTrack.vec.w.x),  ! direc. cos.x in the current detector system.
 c     *  sngl(aTrack.vec.w.y),  ! direc. cos.y
-c     *  sngl(aTrack.vec.w.z),  ! direc. cos.z
-c     * sngl(-angle.r(3)) ,
-c     * sngl(aTrack.vec.coszenith),  ! cos of zenith angle
+     *  sngl(aTrack.vec.w.z),  ! direc. cos.z
+     * sngl(-angle.r(3)) ,
+     * sngl(aTrack.vec.coszenith),  ! cos of zenith angle
 c     * sngl(inci.p.fm.p(4)-inci.p.mass)/Code2massN(int(inci.p.code)),
-c     * inci.p.code
+     * inci.p.code
 c         if(aTrack.p.code .eq. kelec) then
 c            write(*, *) aTrack.where
 c         endif
@@ -364,7 +364,7 @@ c     *           sngl(bsin), sngl(sumsize), sngl(teta), sngl(fai)
          endif
       enddo
  100  continue
-       if(nnn .ge . 4) then
+       if(nnn .lt. 0) then
          call cqIncident(inci, angle)
          call cqFirstID(fdepth)
          fdepth = fdepth * 0.1         ! in g/cm2
