@@ -1,3 +1,5 @@
+      integer MaxIntMdls
+      parameter(MaxIntMdls=8) 
 c                    variables in Event generator
         record /ptcl/ Pjlab,     ! projectile in lab.
      *                Pjtatr,    ! projectile in target at rest system
@@ -23,7 +25,15 @@ c                                  two recoiled leadings) in cms.
      *          Ptnorm,    ! average Pt for normalization (pion's at this E)
      *          Probpower, ! Probability of power type pt.
      *          Avncharged ! Average number of charge particles 
-c                                  
+
+        real*8  InteErg(MaxIntMdls) ! energy bound for interaction model.
+        character*16 ModelList(MaxIntMdls) ! corresponding model name.
+
+c                             
+        character*16 ActiveMdl  ! interaction model to be applied to the
+                           !    current particle
+
+        
         integer  Nnnb,    ! # of nn~
      *           Nkaon,   ! # of kaons
      *           Nddb,    ! # of DD~
@@ -32,14 +42,21 @@ c
      *           Nkch,    ! # of k+, k- ( Nkaon = Nkch + Nk0)
      *           Npi0,    ! # of pi 0
      *           Nch,     ! # of all charged secondaries
-     *           Neta     ! # of eta
-
+     *           Neta,    ! # of eta
+     *           NoOfMdls ! # of interaction models being used.
 
         common /Zevhnv/  Pjlab, Pjtatr, Pjcms, Rpjlab, Rpjtatr,
      *                    Rpjcms, Tglab, Tgpatr, Tgcms, Rtglab,
      *                    Rtgpatr, Rtgcms, Cmsp, Missingp, 
+     *                    InteErg,
      *                    Efrs, Powerexp, Powerp, Ptnorm, Probpower,
      *                    Avncharged, Nch,
      *                    Nnnb, Nkaon, Nddb, Npic, Nk0, Nkch, Npi0,
-     *                    Neta
+     *                    Neta, NoOfMdls
+       common /Zevhnvc/ ModelList, ActiveMdl
+
+
+
+
+
 
