@@ -46,17 +46,27 @@ ccc            if(TrackBefMove.pos.height .lt. AlmostVacH) then
             call cmaxCasLen(TrackBefMove, ztrunc)
             if(TrackBefMove.p.fm.p(4) .gt. LpmBremEmin
      *         .and. LpmEffect) then
-               ztrunc = min(TrackBefMove.pos.depth/10., ztrunc)
+               ztrunc =
+     *         max( min(TrackBefMove.pos.depth/10., ztrunc), 
+     *              30.d0 )
             endif
 c            call cthick2len(TrackBefMove.pos.height, 
 c     *         TrackBefMove.vec.coszenith, ztrunc, leng, thick, jcut)
             call cthick2len(TrackBefMove,
      *          ztrunc, leng, thick, jcut)
+c////////////
+c            write(*,*) ' after thick2len, leng=',leng,
+c     *         ' thick=',thick, ' jcut=',jcut, ' rmg=',rmg
+c////////////////////
 c                 thick may have been changed to shorter one.
             if(rmg .lt. leng) then
                thick = clen2thick(TrackBefMove.pos.height,
      *              TrackBefMove.vec.coszenith, rmg)
                leng = rmg
+c//////////////
+c               write(*,*) ' thick by len2th=', thick, ' len=rmg=',
+c     *         leng
+c////////////////
             endif
 cc            else
 cc               thick = AlmostVacT
